import * as React from 'react';
import React__default from 'react';
import { Placement } from '@floating-ui/react';
import * as react_jsx_runtime from 'react/jsx-runtime';

type MenuProps = {
	/**
	 * The component to use to open the menu, e.g. a ButtonIcon, a Button, etc.
	 */
	trigger: React__default.ReactNode;
	/**
	 * The children to render.
	 */
	children?: React__default.ReactNode;
	/**
	 * The default location of the popup.
	 * @default "bottom-start"
	 */
	defaultPlacement?: Placement;
	/**
	 * The type of focus for the Button. This will change the color
	 * of the focus ring around the Button.
	 */
	focusMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * The type of Button trigger. This will change the color of the Button.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * The label to use for the menu button.
	 */
	label?: string;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange?: (open: boolean) => void;
};

type MenuItemProps = {
	/**
	 * The label to use for the menu item.
	 */
	label?: string;
	/**
	 * Whether or not the menu item is disabled.
	 * @default false
	 */
	disabled?: boolean;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React__default.ReactNode;
	/**
	 * Disable internal menu item behavior (click, focus, etc.).
	 */
	raw?: boolean;
	/**
	 * Whether or not the menu should close when the menu item is selected.
	 */
	ignoreClick?: boolean;
};

type MenuSeparatorProps = React__default.HTMLAttributes<HTMLDivElement>;

declare const MenuComponent: React__default.ForwardRefExoticComponent<Omit<MenuProps & React__default.HTMLProps<HTMLButtonElement>, "ref"> & React__default.RefAttributes<HTMLButtonElement>>;
declare const Menu: React__default.ForwardRefExoticComponent<Omit<MenuProps & React__default.HTMLProps<HTMLButtonElement>, "ref"> & React__default.RefAttributes<HTMLButtonElement>>;

declare const MenuItem: React.ForwardRefExoticComponent<MenuItemProps & React.ButtonHTMLAttributes<HTMLButtonElement> & React.RefAttributes<HTMLButtonElement>>;
declare const MenuSeparator: ({ className, ...props }: MenuSeparatorProps) => react_jsx_runtime.JSX.Element;

export { Menu, MenuComponent, MenuItem, MenuSeparator };
